@@ -9,26 +9,30 @@
 */
 
 #include "kwidgetjobtracker.h"
-#include "kwidgetjobtracker_p.h"
+#include "debug.h"
 #include "kjobtrackerformatters_p.h"
+#include "kwidgetjobtracker_p.h"
 
 #include <QCoreApplication>
 #include <QDir>
-#include <QProcess>
-#include <QTimer>
+#include <QEvent>
+#include <QGridLayout>
 #include <QLabel>
+#include <QProcess>
 #include <QProgressBar>
 #include <QPushButton>
-#include <QVBoxLayout>
-#include <QGridLayout>
-#include <QEvent>
+#include <QStandardPaths>
 #include <QStyle>
+#include <QTimer>
+#include <QVBoxLayout>
 
-#include <KSqueezedTextLabel>
 #include <KSeparator>
+#include <KSqueezedTextLabel>
 
-void KWidgetJobTracker::Private::_k_showProgressWidget()
+void KWidgetJobTrackerPrivate::_k_showProgressWidget()
 {
+    Q_Q(KWidgetJobTracker);
+
     if (progressWidgetsToBeShown.isEmpty()) {
         return;
     }
@@ -47,23 +51,24 @@ void KWidgetJobTracker::Private::_k_showProgressWidget()
 }
 
 KWidgetJobTracker::KWidgetJobTracker(QWidget *parent)
-    : KAbstractWidgetJobTracker(parent), d(new Private(parent, this))
+    : KAbstractWidgetJobTracker(*new KWidgetJobTrackerPrivate(parent, this), parent)
 {
 }
 
-KWidgetJobTracker::~KWidgetJobTracker()
-{
-    delete d;
-}
+KWidgetJobTracker::~KWidgetJobTracker() = default;
 
 QWidget *KWidgetJobTracker::widget(KJob *job)
 {
+    Q_D(KWidgetJobTracker);
+
     return d->progressWidget.value(job, nullptr);
 }
 
 void KWidgetJobTracker::registerJob(KJob *job)
 {
-    Private::ProgressWidget *vi = new Private::ProgressWidget(job, this, d->parent);
+    Q_D(KWidgetJobTracker);
+
+    auto *vi = new KWidgetJobTrackerPrivate::ProgressWidget(job, this, d->parent);
     vi->jobRegistered = true;
     vi->setAttribute(Qt::WA_DeleteOnClose);
     d->progressWidget.insert(job, vi);
@@ -76,10 +81,12 @@ void KWidgetJobTracker::registerJob(KJob *job)
 
 void KWidgetJobTracker::unregisterJob(KJob *job)
 {
+    Q_D(KWidgetJobTracker);
+
     KAbstractWidgetJobTracker::unregisterJob(job);
 
     d->progressWidgetsToBeShown.removeAll(job);
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -90,7 +97,9 @@ void KWidgetJobTracker::unregisterJob(KJob *job)
 
 bool KWidgetJobTracker::keepOpen(KJob *job) const
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(const KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return false;
     }
@@ -98,21 +107,23 @@ bool KWidgetJobTracker::keepOpen(KJob *job) const
     return pWidget->keepOpenCheck->isChecked();
 }
 
-void KWidgetJobTracker::infoMessage(KJob *job, const QString &plain, const QString &rich)
+void KWidgetJobTracker::infoMessage(KJob *job, const QString &message)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
 
-    pWidget->infoMessage(plain, rich);
+    pWidget->infoMessage(message);
 }
 
-void KWidgetJobTracker::description(KJob *job, const QString &title,
-                                    const QPair<QString, QString> &field1,
-                                    const QPair<QString, QString> &field2)
+void KWidgetJobTracker::description(KJob *job, const QString &title, const QPair<QString, QString> &field1, const QPair<QString, QString> &field2)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -122,7 +133,9 @@ void KWidgetJobTracker::description(KJob *job, const QString &title,
 
 void KWidgetJobTracker::totalAmount(KJob *job, KJob::Unit unit, qulonglong amount)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -132,7 +145,9 @@ void KWidgetJobTracker::totalAmount(KJob *job, KJob::Unit unit, qulonglong amoun
 
 void KWidgetJobTracker::processedAmount(KJob *job, KJob::Unit unit, qulonglong amount)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -142,7 +157,9 @@ void KWidgetJobTracker::processedAmount(KJob *job, KJob::Unit unit, qulonglong a
 
 void KWidgetJobTracker::percent(KJob *job, unsigned long percent)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -152,7 +169,9 @@ void KWidgetJobTracker::percent(KJob *job, unsigned long percent)
 
 void KWidgetJobTracker::speed(KJob *job, unsigned long value)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -162,7 +181,9 @@ void KWidgetJobTracker::speed(KJob *job, unsigned long value)
 
 void KWidgetJobTracker::slotClean(KJob *job)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -172,7 +193,9 @@ void KWidgetJobTracker::slotClean(KJob *job)
 
 void KWidgetJobTracker::suspended(KJob *job)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -182,7 +205,9 @@ void KWidgetJobTracker::suspended(KJob *job)
 
 void KWidgetJobTracker::resumed(KJob *job)
 {
-    KWidgetJobTracker::Private::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
+    Q_D(KWidgetJobTracker);
+
+    KWidgetJobTrackerPrivate::ProgressWidget *pWidget = d->progressWidget.value(job, nullptr);
     if (!pWidget) {
         return;
     }
@@ -190,12 +215,12 @@ void KWidgetJobTracker::resumed(KJob *job)
     pWidget->resumed();
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::ref()
+void KWidgetJobTrackerPrivate::ProgressWidget::ref()
 {
     ++refCount;
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::deref()
+void KWidgetJobTrackerPrivate::ProgressWidget::deref()
 {
     if (refCount) {
         --refCount;
@@ -210,7 +235,7 @@ void KWidgetJobTracker::Private::ProgressWidget::deref()
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::closeNow()
+void KWidgetJobTrackerPrivate::ProgressWidget::closeNow()
 {
     close();
 
@@ -223,13 +248,13 @@ void KWidgetJobTracker::Private::ProgressWidget::closeNow()
     //   last one is still running. We remove its reference on the map. Wrong.
     // For that reason we have to check if the map stores the widget as the current one.
     // ereslibre
-    if (tracker->d->progressWidget[job] == this) {
-        tracker->d->progressWidget.remove(job);
-        tracker->d->progressWidgetsToBeShown.removeAll(job);
+    if (tracker->d_func()->progressWidget[job] == this) {
+        tracker->d_func()->progressWidget.remove(job);
+        tracker->d_func()->progressWidgetsToBeShown.removeAll(job);
     }
 }
 
-bool KWidgetJobTracker::Private::ProgressWidget::eventFilter(QObject *watched, QEvent *event)
+bool KWidgetJobTrackerPrivate::ProgressWidget::eventFilter(QObject *watched, QEvent *event)
 {
     // Handle context menu events for the source/dest labels here, so that we are ref()ed while the
     // menu is exec()ed, to avoid a crash if the job finishes meanwhile. #159621.
@@ -243,22 +268,17 @@ bool KWidgetJobTracker::Private::ProgressWidget::eventFilter(QObject *watched, Q
     return QWidget::eventFilter(watched, event);
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::infoMessage(const QString &plain, const QString &/*rich*/)
+void KWidgetJobTrackerPrivate::ProgressWidget::infoMessage(const QString &message)
 {
-    speedLabel->setText(plain);
+    speedLabel->setText(message);
     speedLabel->setAlignment(speedLabel->alignment() & ~Qt::TextWordWrap);
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::description(const QString &title,
-        const QPair<QString, QString> &field1,
-        const QPair<QString, QString> &field2)
+void KWidgetJobTrackerPrivate::ProgressWidget::description(const QString &title, const QPair<QString, QString> &field1, const QPair<QString, QString> &field2)
 {
     setWindowTitle(title);
     caption = title;
-    sourceInvite->setText(
-        QCoreApplication::translate("KWidgetJobTracker",
-            "%1:", "%1 is the label, we add a ':' to it"
-            ).arg(field1.first));
+    sourceInvite->setText(QCoreApplication::translate("KWidgetJobTracker", "%1:", "%1 is the label, we add a ':' to it").arg(field1.first));
     sourceEdit->setText(field1.second);
 
     if (field2.first.isEmpty()) {
@@ -266,15 +286,12 @@ void KWidgetJobTracker::Private::ProgressWidget::description(const QString &titl
     } else {
         setDestVisible(true);
         checkDestination(QUrl::fromUserInput(field2.second)); // path or URL
-        destInvite->setText(
-            QCoreApplication::translate("KWidgetJobTracker",
-                "%1:", "%1 is the label, we add a ':' to it"
-                ).arg(field2.first));
+        destInvite->setText(QCoreApplication::translate("KWidgetJobTracker", "%1:", "%1 is the label, we add a ':' to it").arg(field2.first));
         destEdit->setText(field2.second);
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::totalAmount(KJob::Unit unit, qulonglong amount)
+void KWidgetJobTrackerPrivate::ProgressWidget::totalAmount(KJob::Unit unit, qulonglong amount)
 {
     switch (unit) {
     case KJob::Bytes:
@@ -312,10 +329,14 @@ void KWidgetJobTracker::Private::ProgressWidget::totalAmount(KJob::Unit unit, qu
         totalItems = amount;
         showTotals();
         break;
+
+    case KJob::UnitsCount:
+        Q_UNREACHABLE();
+        break;
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::processedAmount(KJob::Unit unit, qulonglong amount)
+void KWidgetJobTrackerPrivate::ProgressWidget::processedAmount(KJob::Unit unit, qulonglong amount)
 {
     QString tmp;
 
@@ -330,7 +351,7 @@ void KWidgetJobTracker::Private::ProgressWidget::processedAmount(KJob::Unit unit
             //~ singular %1 of %2 complete
             //~ plural %1 of %2 complete
             tmp = QCoreApplication::translate("KWidgetJobTracker", "%1 of %2 complete", "", amount)
-                  .arg(KJobTrackerFormatters::byteSize(amount), KJobTrackerFormatters::byteSize(totalSize));
+                      .arg(KJobTrackerFormatters::byteSize(amount), KJobTrackerFormatters::byteSize(totalSize));
         } else {
             tmp = KJobTrackerFormatters::byteSize(amount);
         }
@@ -379,19 +400,24 @@ void KWidgetJobTracker::Private::ProgressWidget::processedAmount(KJob::Unit unit
             return;
         }
         processedItems = amount;
+        //~ singular %1 / %n item
+        //~ plural %1 / %n items
         tmp = QCoreApplication::translate("KWidgetJobTracker", "%1 / %n item(s)", "", totalItems).arg(processedItems);
         progressLabel->setText(tmp);
         break;
+
+    case KJob::UnitsCount:
+        Q_UNREACHABLE();
+        break;
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::percent(unsigned long percent)
+void KWidgetJobTrackerPrivate::ProgressWidget::percent(unsigned long percent)
 {
     QString title = caption + QLatin1String(" (");
 
     if (totalSizeKnown) {
-        title += QCoreApplication::translate("KWidgetJobTracker", "%1% of %2").arg(percent).arg(
-                     KJobTrackerFormatters::byteSize(totalSize));
+        title += QCoreApplication::translate("KWidgetJobTracker", "%1% of %2").arg(percent).arg(KJobTrackerFormatters::byteSize(totalSize));
     } else if (totalFiles) {
         //~ singular %1% of %n file
         //~ plural %1% of %n files
@@ -407,7 +433,7 @@ void KWidgetJobTracker::Private::ProgressWidget::percent(unsigned long percent)
     setWindowTitle(title);
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::speed(unsigned long value)
+void KWidgetJobTrackerPrivate::ProgressWidget::speed(unsigned long value)
 {
     if (value == 0) {
         speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "Stalled"));
@@ -417,14 +443,15 @@ void KWidgetJobTracker::Private::ProgressWidget::speed(unsigned long value)
             const int remaining = 1000 * (totalSize - processedSize) / value;
             //~ singular %1/s (%2 remaining)
             //~ plural %1/s (%2 remaining)
-            speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s (%2 remaining)", "", remaining).arg(speedStr, KJobTrackerFormatters::duration(remaining)));
+            speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s (%2 remaining)", "", remaining)
+                                    .arg(speedStr, KJobTrackerFormatters::duration(remaining)));
         } else { // total size is not known (#24228)
             speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s", "speed in bytes per second").arg(speedStr));
         }
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::slotClean()
+void KWidgetJobTrackerPrivate::ProgressWidget::slotClean()
 {
     percent(100);
     cancelClose->setText(QCoreApplication::translate("KWidgetJobTracker", "&Close"));
@@ -442,24 +469,23 @@ void KWidgetJobTracker::Private::ProgressWidget::slotClean()
         if (!s) {
             s = 1;
         }
-        speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s (done)").arg(
-                                KJobTrackerFormatters::byteSize(1000 * totalSize / s)));
+        speedLabel->setText(QCoreApplication::translate("KWidgetJobTracker", "%1/s (done)").arg(KJobTrackerFormatters::byteSize(1000 * totalSize / s)));
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::suspended()
+void KWidgetJobTrackerPrivate::ProgressWidget::suspended()
 {
     pauseButton->setText(QCoreApplication::translate("KWidgetJobTracker", "&Resume"));
     suspendedProperty = true;
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::resumed()
+void KWidgetJobTrackerPrivate::ProgressWidget::resumed()
 {
     pauseButton->setText(QCoreApplication::translate("KWidgetJobTracker", "&Pause"));
     suspendedProperty = false;
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::closeEvent(QCloseEvent *event)
+void KWidgetJobTrackerPrivate::ProgressWidget::closeEvent(QCloseEvent *event)
 {
     if (jobRegistered && tracker->stopOnClose(job)) {
         tracker->slotStop(job);
@@ -468,7 +494,7 @@ void KWidgetJobTracker::Private::ProgressWidget::closeEvent(QCloseEvent *event)
     QWidget::closeEvent(event);
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::init()
+void KWidgetJobTrackerPrivate::ProgressWidget::init()
 {
     setWindowIcon(QIcon::fromTheme(QStringLiteral("document-save"), windowIcon()));
 
@@ -499,6 +525,7 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     topLayout->addLayout(progressHBox);
 
     progressBar = new QProgressBar(this);
+    progressBar->setFormat(QCoreApplication::translate("KWidgetJobTracker", "%p%", "Progress bar percent value, %p is the value, % is the percent sign. Make sure to include %p in your translation."));
     progressBar->setMaximum(0); // want a jumping progress bar if percent is not emitted
     progressHBox->addWidget(progressBar);
 
@@ -513,8 +540,7 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     arrowButton->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
     arrowButton->setToolTip(QCoreApplication::translate("KWidgetJobTracker", "Click this to expand the dialog, to show details"));
     arrowState = Qt::DownArrow;
-    connect(arrowButton, &QPushButton::clicked,
-            this, &KWidgetJobTracker::Private::ProgressWidget::arrowClicked);
+    connect(arrowButton, &QPushButton::clicked, this, &KWidgetJobTrackerPrivate::ProgressWidget::arrowClicked);
     hBox->addWidget(arrowButton);
     hBox->addStretch(1);
 
@@ -529,8 +555,7 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
 
     pauseButton = new QPushButton(QCoreApplication::translate("KWidgetJobTracker", "&Pause"), this);
     pauseButton->setVisible(job && (job->capabilities() & KJob::Suspendable));
-    connect(pauseButton, &QPushButton::clicked,
-            this, &KWidgetJobTracker::Private::ProgressWidget::pauseResumeClicked);
+    connect(pauseButton, &QPushButton::clicked, this, &KWidgetJobTrackerPrivate::ProgressWidget::pauseResumeClicked);
     hBox->addWidget(pauseButton);
 
     hBox = new QHBoxLayout();
@@ -549,8 +574,7 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     progressLabel->hide();
 
     keepOpenCheck = new QCheckBox(QCoreApplication::translate("KWidgetJobTracker", "&Keep this window open after transfer is complete"), this);
-    connect(keepOpenCheck, &QCheckBox::toggled,
-            this, &KWidgetJobTracker::Private::ProgressWidget::keepOpenToggled);
+    connect(keepOpenCheck, &QCheckBox::toggled, this, &KWidgetJobTrackerPrivate::ProgressWidget::keepOpenToggled);
     topLayout->addWidget(keepOpenCheck);
     keepOpenCheck->hide();
 
@@ -558,15 +582,13 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     topLayout->addLayout(hBox);
 
     openFile = new QPushButton(QCoreApplication::translate("KWidgetJobTracker", "Open &File"), this);
-    connect(openFile, &QPushButton::clicked,
-            this, &KWidgetJobTracker::Private::ProgressWidget::openFileClicked);
+    connect(openFile, &QPushButton::clicked, this, &KWidgetJobTrackerPrivate::ProgressWidget::openFileClicked);
     hBox->addWidget(openFile);
     openFile->setEnabled(false);
     openFile->hide();
 
     openLocation = new QPushButton(QCoreApplication::translate("KWidgetJobTracker", "Open &Destination"), this);
-    connect(openLocation, &QPushButton::clicked,
-            this, &KWidgetJobTracker::Private::ProgressWidget::openLocationClicked);
+    connect(openLocation, &QPushButton::clicked, this, &KWidgetJobTrackerPrivate::ProgressWidget::openLocationClicked);
     hBox->addWidget(openLocation);
     openLocation->hide();
 
@@ -575,8 +597,7 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     cancelClose = new QPushButton(this);
     cancelClose->setText(QCoreApplication::translate("KWidgetJobTracker", "&Cancel"));
     cancelClose->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
-    connect(cancelClose, &QPushButton::clicked,
-            this, &KWidgetJobTracker::Private::ProgressWidget::cancelClicked);
+    connect(cancelClose, &QPushButton::clicked, this, &KWidgetJobTrackerPrivate::ProgressWidget::cancelClicked);
     hBox->addWidget(cancelClose);
 
     resize(sizeHint());
@@ -585,7 +606,7 @@ void KWidgetJobTracker::Private::ProgressWidget::init()
     setWindowTitle(QCoreApplication::translate("KWidgetJobTracker", "Progress Dialog")); // show something better than kuiserver
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::showTotals()
+void KWidgetJobTrackerPrivate::ProgressWidget::showTotals()
 {
     // Show the totals in the progress label, if we still haven't
     // processed anything. This is useful when the stat'ing phase
@@ -593,19 +614,25 @@ void KWidgetJobTracker::Private::ProgressWidget::showTotals()
     if (processedFiles == 0 && processedDirs == 0 && processedItems == 0) {
         QString total;
         if (totalItems > 1) {
+            //~ singular %n item
+            //~ plural %n items
             total = QCoreApplication::translate("KWidgetJobTracker", "%n item(s)", "", totalItems);
             progressLabel->setText(total);
         } else {
             if (totalDirs > 1) {
+                //~ singular %n folder
+                //~ plural %n folders
                 total = QCoreApplication::translate("KWidgetJobTracker", "%n folder(s)", "", totalDirs) + QLatin1String("   ");
             }
+            //~ singular %n file
+            //~ plural %n files
             total += QCoreApplication::translate("KWidgetJobTracker", "%n file(s)", "", totalFiles);
             progressLabel->setText(total);
         }
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::setDestVisible(bool visible)
+void KWidgetJobTrackerPrivate::ProgressWidget::setDestVisible(bool visible)
 {
     // We can't hide the destInvite/destEdit labels,
     // because it screws up the QGridLayout.
@@ -621,14 +648,14 @@ void KWidgetJobTracker::Private::ProgressWidget::setDestVisible(bool visible)
     setMaximumHeight(sizeHint().height());
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::checkDestination(const QUrl &dest)
+void KWidgetJobTrackerPrivate::ProgressWidget::checkDestination(const QUrl &dest)
 {
     bool ok = true;
 
     if (dest.isLocalFile()) {
         const QString path = dest.toLocalFile();
         if (path.contains(QDir::tempPath())) {
-            ok = false;    // it's in the tmp directory
+            ok = false; // it's in the tmp directory
         }
     }
 
@@ -641,28 +668,43 @@ void KWidgetJobTracker::Private::ProgressWidget::checkDestination(const QUrl &de
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::keepOpenToggled(bool keepOpen)
+void KWidgetJobTrackerPrivate::ProgressWidget::keepOpenToggled(bool keepOpen)
 {
     if (keepOpen) {
-        Q_ASSERT(!tracker->d->eventLoopLocker);
-        tracker->d->eventLoopLocker = new QEventLoopLocker;
+        Q_ASSERT(!tracker->d_func()->eventLoopLocker);
+        tracker->d_func()->eventLoopLocker = new QEventLoopLocker;
     } else {
-        delete tracker->d->eventLoopLocker;
-        tracker->d->eventLoopLocker = nullptr;
+        delete tracker->d_func()->eventLoopLocker;
+        tracker->d_func()->eventLoopLocker = nullptr;
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::openFileClicked()
+static QString findKdeOpen()
 {
-    QProcess::startDetached(QStringLiteral("kde-open"), QStringList() << location.toDisplayString());
+    const QString exec = QStandardPaths::findExecutable(QStringLiteral("kde-open"));
+    if (exec.isEmpty()) {
+        qCWarning(KJOBWIDGETS) << "Could not find kde-open executable in PATH";
+    }
+    return exec;
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::openLocationClicked()
+void KWidgetJobTrackerPrivate::ProgressWidget::openFileClicked()
 {
-    QProcess::startDetached(QStringLiteral("kde-open"), QStringList() << location.adjusted(QUrl::RemoveFilename).toString());
+    const QString exec = findKdeOpen();
+    if (!exec.isEmpty()) {
+        QProcess::startDetached(exec, QStringList() << location.toDisplayString());
+    }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::pauseResumeClicked()
+void KWidgetJobTrackerPrivate::ProgressWidget::openLocationClicked()
+{
+    const QString exec = findKdeOpen();
+    if (!exec.isEmpty()) {
+        QProcess::startDetached(exec, QStringList() << location.adjusted(QUrl::RemoveFilename).toString());
+    }
+}
+
+void KWidgetJobTrackerPrivate::ProgressWidget::pauseResumeClicked()
 {
     if (jobRegistered && !suspendedProperty) {
         tracker->slotSuspend(job);
@@ -671,7 +713,7 @@ void KWidgetJobTracker::Private::ProgressWidget::pauseResumeClicked()
     }
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::cancelClicked()
+void KWidgetJobTrackerPrivate::ProgressWidget::cancelClicked()
 {
     if (jobRegistered) {
         tracker->slotStop(job);
@@ -679,17 +721,17 @@ void KWidgetJobTracker::Private::ProgressWidget::cancelClicked()
     closeNow();
 }
 
-void KWidgetJobTracker::Private::ProgressWidget::arrowClicked()
+void KWidgetJobTrackerPrivate::ProgressWidget::arrowClicked()
 {
     if (arrowState == Qt::DownArrow) {
-        //The arrow is in the down position, dialog is collapsed, expand it and change icon.
+        // The arrow is in the down position, dialog is collapsed, expand it and change icon.
         progressLabel->show();
         speedLabel->show();
         arrowButton->setIcon(QIcon::fromTheme(QStringLiteral("arrow-up")));
         arrowButton->setToolTip(QCoreApplication::translate("KWidgetJobTracker", "Click this to collapse the dialog, to hide details"));
         arrowState = Qt::UpArrow;
     } else {
-        //Collapse the dialog
+        // Collapse the dialog
         progressLabel->hide();
         speedLabel->hide();
         arrowButton->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
